@@ -2,9 +2,9 @@
 
 package DateTimeX::strftimeq;
 
-our $DATE = '2019-11-19'; # DATE
+our $DATE = '2019-11-20'; # DATE
 our $DIST = 'DateTimeX-strftimeq'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -110,11 +110,11 @@ DateTimeX::strftimeq - POSIX::strftime() with support for embedded perl code in
 
 =head1 VERSION
 
-This document describes version 0.002 of DateTimeX::strftimeq (from Perl distribution DateTimeX-strftimeq), released on 2019-11-19.
+This document describes version 0.003 of DateTimeX::strftimeq (from Perl distribution DateTimeX-strftimeq), released on 2019-11-20.
 
 =head1 SYNOPSIS
 
- use DateTimeX::strftime; # by default exports strftimeq()
+ use DateTimeX::strftimeq; # by default exports strftimeq()
 
  my @time = localtime();
  print strftimeq '<%6Y-%m-%d>', @time; # <002019-11-19>
